<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>AbstractContent</name>
    <message>
        <location filename="../items/AbstractContent.cpp" line="56"/>
        <source>Hold down SHIFT for ignoring aspect ratio.
Double click to restore the aspect ratio.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractContent.cpp" line="64"/>
        <source>Hold down SHIFT to snap the rotation.
Double click to align the object.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractContent.cpp" line="75"/>
        <source>Change properties...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractContent.cpp" line="80"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractContent.cpp" line="455"/>
        <source>Choose the Image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractContent.cpp" line="455"/>
        <source>Images (*.jpeg *.jpg *.png *.bmp *.tif *.tiff)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractContent.cpp" line="494"/>
        <source>File Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractContent.cpp" line="494"/>
        <source>Error saving the Object to &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AbstractProperties</name>
    <message>
        <location filename="../items/AbstractProperties.ui" line="21"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="35"/>
        <source>Stacking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="72"/>
        <source>Raise</source>
        <translation type="unfinished">Anheben</translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="86"/>
        <source>Lower</source>
        <translation type="unfinished">Absenken</translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="137"/>
        <source>Operations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="174"/>
        <source>Save</source>
        <translation type="unfinished">Speichern</translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="188"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="58"/>
        <source>To Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="100"/>
        <source>To Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="160"/>
        <source>To Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="227"/>
        <source>Looks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="234"/>
        <source>apply to all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/AbstractProperties.ui" line="299"/>
        <source>Show Reflection</source>
        <translation type="unfinished">Zeige Reflektionen</translation>
    </message>
</context>
<context>
    <name>ColorAction</name>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="260"/>
        <source>Text Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Desk</name>
    <message>
        <location filename="../Desk.cpp" line="547"/>
        <source>Back</source>
        <translation type="unfinished">Back</translation>
    </message>
    <message>
        <location filename="../Desk.cpp" line="551"/>
        <source>Front</source>
        <translation type="unfinished">Vordergrund</translation>
    </message>
</context>
<context>
    <name>FotoWall</name>
    <message>
        <location filename="../FotoWall.cpp" line="328"/>
        <source>Select one or more pictures to add</source>
        <translation type="unfinished">Wähle ein oder mehrere biklder aus</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="328"/>
        <source>Images (%1)</source>
        <translation type="unfinished">Bild(er) (%1)</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="169"/>
        <source>This function is being rewritten for version 0.6.
In the meantime, while not the optimum, you can still get high quality results ;-)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="171"/>
        <source>Choose the Image file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="171"/>
        <source>Images (*.jpeg *.jpg *.png *.bmp *.tif *.tiff)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="197"/>
        <source>Rendering Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="197"/>
        <source>Error rendering to the file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="201"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="259"/>
        <source>Top bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="265"/>
        <source>Bottom bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="273"/>
        <source>Set title...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="277"/>
        <source>Clear title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="293"/>
        <source>export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="304"/>
        <location filename="../FotoWall.cpp" line="314"/>
        <source>print...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="345"/>
        <source>Opening the Web Tutorial</source>
        <translation type="unfinished">Öffne die Anleitung im Internet</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="345"/>
        <source>The Tutorial is provided on Fosswire by Peter Upfold.
Do you want to open the web page?</source>
        <translation type="unfinished">Die Anleitung wird auf Fosswire von Peter Upfold angeboten.
Willst Du die Webseite aufrufen?</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="352"/>
        <location filename="../FotoWall.cpp" line="367"/>
        <source>Select Layout file</source>
        <translation type="unfinished">Wähle eine Layoutdatei aus</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="358"/>
        <location filename="../FotoWall.cpp" line="375"/>
        <source>File Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="358"/>
        <source>Error loading Layout from the file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="375"/>
        <source>Error saving the Layout to the file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="425"/>
        <source>Title</source>
        <translation type="unfinished">Titel</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="425"/>
        <source>Insert the title</source>
        <translation type="unfinished">Gebe eine Überschrift ein</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="169"/>
        <source>Warning</source>
        <translation type="unfinished">Warnung</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="201"/>
        <source>The target image is %1 bytes long</source>
        <translation type="unfinished">Das berechnete Bild isr %1 Byte(s) lang</translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="113"/>
        <source>add pictures</source>
        <translation type="unfinished">Bilder hinzufügen</translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="163"/>
        <source>FotoWall</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="291"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;help&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;tutorial&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;help&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;tutorial&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="136"/>
        <source>add text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="168"/>
        <source>CD Cover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="173"/>
        <source>DVD Cover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="221"/>
        <source>Decorations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="194"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;help&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;introduction&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="254"/>
        <source>load</source>
        <translation type="unfinished">Laden</translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="267"/>
        <source>save</source>
        <translation type="unfinished">Speichen</translation>
    </message>
    <message>
        <location filename="../FotoWall.ui" line="277"/>
        <source>quit</source>
        <translation type="unfinished">Beenden</translation>
    </message>
</context>
<context>
    <name>GlowEffectDialog</name>
    <message>
        <location filename="../GlowEffectDialog.ui" line="13"/>
        <source>Glow effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../GlowEffectDialog.ui" line="19"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Scroll &lt;/span&gt;wheel to change the radius. &lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Click&lt;/span&gt; on the picture to get a preview.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../GlowEffectDialog.ui" line="49"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../GlowEffectDialog.ui" line="56"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HtmlTextEdit</name>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="202"/>
        <source>Insert HTML entity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PictureContent</name>
    <message>
        <location filename="../items/PictureContent.cpp" line="34"/>
        <location filename="../items/PictureContent.cpp" line="74"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <location filename="../items/PictureContent.cpp" line="38"/>
        <source>Flip horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureContent.cpp" line="44"/>
        <source>Flip vertically</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PictureProperties</name>
    <message>
        <location filename="../items/PictureProperties.cpp" line="29"/>
        <source>Picture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.cpp" line="34"/>
        <source>Invert colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.cpp" line="35"/>
        <source>Invert the colors of the picture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.cpp" line="37"/>
        <source>NVG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.cpp" line="38"/>
        <source>Set the colors to levels of gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.cpp" line="40"/>
        <source>Black and White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.cpp" line="42"/>
        <source>Glow effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.cpp" line="32"/>
        <source>No effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.ui" line="25"/>
        <source>Transform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.ui" line="48"/>
        <source>Invert</source>
        <translation type="unfinished">Invert</translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.ui" line="62"/>
        <source>Flip</source>
        <translation type="unfinished">Flip</translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.ui" line="101"/>
        <source>Effects</source>
        <translation type="unfinished">Effekte</translation>
    </message>
    <message>
        <location filename="../items/PictureProperties.ui" line="108"/>
        <source>apply to all</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RichTextEditorDialog</name>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="737"/>
        <source>Rich Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="738"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RichTextEditorToolBar</name>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="395"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="396"/>
        <source>CTRL+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="401"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="402"/>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="407"/>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="408"/>
        <source>CTRL+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="447"/>
        <source>Superscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="453"/>
        <source>Subscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="467"/>
        <source>Insert &amp;Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="554"/>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../3rdparty/richtextedit/richtexteditor.cpp" line="554"/>
        <source>Images (*.jpeg *.jpg *.png *.bmp *.tif *.tiff)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SizeDialog</name>
    <message>
        <location filename="../FotoWall.cpp" line="148"/>
        <source>The aspect ratio must be kept</source>
        <translation type="unfinished">Das Zeitenverhältnis bleibt erhalten</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="146"/>
        <source>Select Resolution</source>
        <translation type="unfinished">Wähle die Auflösung</translation>
    </message>
    <message>
        <location filename="../FotoWall.cpp" line="153"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>TextContent</name>
    <message>
        <location filename="../items/TextContent.cpp" line="36"/>
        <source>Right click to Edit the text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../items/TextContent.cpp" line="50"/>
        <source>insert text here...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextProperties</name>
    <message>
        <location filename="../items/TextProperties.cpp" line="29"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
